#
# spec file for package perl-YAML
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name YAML
Name:           perl-YAML
Version:        1.310.0
Release:        2.5
%define cpan_version 1.31
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        YAML Ain't Markup Language™
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/I/IN/INGY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::YAML) >= 1.05
Provides:       perl(YAML) = %{version}
Provides:       perl(YAML::Any) = %{version}
Provides:       perl(YAML::Dumper)
Provides:       perl(YAML::Dumper::Base)
Provides:       perl(YAML::Error)
Provides:       perl(YAML::Loader)
Provides:       perl(YAML::Loader::Base)
Provides:       perl(YAML::Marshall)
Provides:       perl(YAML::Mo)
Provides:       perl(YAML::Node)
Provides:       perl(YAML::Tag)
Provides:       perl(YAML::Type::blessed)
Provides:       perl(YAML::Type::code)
Provides:       perl(YAML::Type::glob)
Provides:       perl(YAML::Type::ref)
Provides:       perl(YAML::Type::regexp)
Provides:       perl(YAML::Type::undef)
Provides:       perl(YAML::Types)
Provides:       perl(YAML::Warning)
Provides:       perl(yaml_mapping)
Provides:       perl(yaml_scalar)
Provides:       perl(yaml_sequence)
%undefine       __perllib_provides
%{perl_requires}

%description
The YAML.pm module implements a YAML Loader and Dumper based on the YAML
1.0 specification. http://www.yaml.org/spec/

YAML is a generic data serialization language that is optimized for human
readability. It can be used to express the data structures of most modern
programming languages. (Including Perl!!!)

For information on the YAML syntax, please refer to the YAML specification.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Dec 28 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.31
  see /usr/share/doc/packages/perl-YAML/Changes
  1.31 Wed Dec 27 07:10:56 AM PST 2023
  - Update docs to recommend YAML::PP
* Tue Jan 28 2020 <timueller+perl@suse.de>
- updated to 1.30
  see /usr/share/doc/packages/perl-YAML/Changes
  1.30 Mon 27 Jan 2020 11:09:46 PM CET
  - Breaking Change: Set $YAML::LoadBlessed default to false to make it more
    secure
* Sun May 12 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.29
  see /usr/share/doc/packages/perl-YAML/Changes
  1.29 Sat 11 May 2019 10:26:54 AM CEST
  - Fix regex for alias to match the one for anchors (PR#214 TINITA)
* Mon Apr 29 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.28
  see /usr/share/doc/packages/perl-YAML/Changes
  1.28 Sun 28 Apr 2019 11:46:21 AM CEST
  - Security fix: only enable loading globs when $LoadCode is set (PR#213
    TINITA)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.27
  see /usr/share/doc/packages/perl-YAML/Changes
  1.27 Sat Nov  3 14:01:26 CET 2018
  - Remove a warning about uninitialized value for perl <= 5.10
* Sat May 19 2018 coolo@suse.com
- updated to 1.26
  see /usr/share/doc/packages/perl-YAML/Changes
  1.26 Fri May 18 21:57:20 CEST 2018
  - Fix bug introduced in 1.25 - loading of quoted string with colon as
    sequence element (tinita, fixes issue#208)
  - Support zero indented block sequences (PR#207 tinita)
* Sat May 12 2018 coolo@suse.com
- updated to 1.25
  see /usr/share/doc/packages/perl-YAML/Changes
  1.25 Fri May 11 19:58:58 CEST 2018
  - Applied several pull requests by tinita
  - Support trailing comments (PR#189, PR#190, PR#191)
  - Remove unused code (PR#192)
  - Use Test::Deep to actually test correctly for class names (PR#193)
  - Fix loading of mapping key which starts with `= ` (PR#194)
  - Fix loading strings with multiple spaces (PR#172)
  - Allow more characters in anchor name (PR#196)
  - Add $YAML::LoadBlessed for disabling loading objects (PR#197)
  - Applied several pull requests by tinita
  - Disable test with long string under certain conditions (PR#201)
  - Quote scalar if it equals '=' (PR#202)
  - Multiple regexp roundtrip does not grow (PR#203)
  - Add support for compact nested block sequences (PR#204)
  - Support reverse order of block scalar indicators (PR#205)
  - Support nested mappings in sequences (PR#206)
* Tue Oct 31 2017 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-YAML/Changes
  1.24 Mon Oct 30 20:31:53 CET 2017
  - Fix $LoadCode (PR#180, PR#181, PR#182 by @mohawk2++)
* Mon Feb 20 2017 coolo@suse.com
- updated to 1.23
  see /usr/share/doc/packages/perl-YAML/Changes
  1.23 Sun Feb 19 22:07:57 CET 2017
  - Fix $YAML::Numify (empty values were converted to 0)
* Wed Feb 15 2017 coolo@suse.com
- updated to 1.22
  see /usr/share/doc/packages/perl-YAML/Changes
  1.22 Tue Feb 14 23:23:08 CET 2017
  - Add $YAML::Numify @perlpunk++
* Sat Dec 24 2016 coolo@suse.com
- updated to 1.21
  see /usr/share/doc/packages/perl-YAML/Changes
  1.21 Fri Dec 23 21:19:15 CET 2016
  - Apply PR/171 (fixes issue/109) @perlpunk++
  - No more "used only once" warnings for $YAML::Indent etc.
  - Apply PR/170 (fixes issue/131) hiratara@cpan.org++
  - Empty mapping value at the end resolves to null (was becoming empty
    string)
  - Apply PR/169 (PR/119) patrick.allen.higgins@gmail.com++
  - Output key in warning when duplicate key was found
  - Apply PR/157 and PR/168 (@lameventanas++ @perlpunk++)
  - Allow reading and writing to IO::Handle
* Sat Dec  3 2016 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-YAML/Changes
  1.20 Fri Dec  2 13:20:33 PST 2016
  - Apply and amend PR/146 (quoted map keys) @preaction++
  - B::Deparse is loaded at runtime now
  - New Feature $YAML::Preserve (Apply PR/9 @fmenabe++)
* Sat Nov 19 2016 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-YAML/Changes
  1.19 Fri Nov 18 19:46:44 CET 2016
  - Apply PR/164 pod (link to YAML::Shell)
  - Apply PR/151 Fix infinite loop for aliases without a name @bubaflub++
  - Apply PR/142 Improve error messages @werekraken++
  - Apply PR/162 Improve error messages
  - Apply PR/163 Trailing spaces after inline seq/map work now
  - Apply PR/154 Add test case for trailing comments @Varadinsky++
* Sat Jul  9 2016 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-YAML/Changes
  1.18 Fri Jul  8 14:52:26 UTC 2016
  - Apply PR/161 @perlpunk++
* Wed Jul  6 2016 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-YAML/Changes
  1.17 Tue Jul  5 20:20:55 UTC 2016
  - Use Mo 0.40
* Mon Jul  4 2016 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-YAML/Changes
  1.16 Sun Jul  3 10:53:06 PDT 2016
  - Apply PR/158 by @bgruening++
  - Fix VERSION issue
* Sun Apr 19 2015 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-YAML/Changes
  1.15 Sat Apr 18 17:03:09 CEST 2015
  - Fix Issue
  - Don't require newlines at end of YAML.
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-YAML/Changes
  1.14 Sat Jan 17 15:32:18 PST 2015
  - Apply PR/145 from @kentnl++
  - Support for QuoteNumericStrings Global Setting
  1.13 Sat Oct 11 18:05:45 CEST 2014
  - Apply PR/140 from @nfg++
  - Disable some warnings in YAML::Any
  1.12 Mon Sep 22 08:24:43 PDT 2014
  - Fix https://rt.cpan.org/Ticket/Display.html?id=97870
  1.11 Fri Aug 29 20:08:20 PDT 2014
  - Apply PR/139. @ehuelsmann++
  1.10 Thu Aug 28 22:53:26 PDT 2014
  - Apply PR/138. @ehuelsmann++
  1.09 Tue Aug 19 16:41:13 PDT 2014
  - Replace tabs with spaces
  1.08 Mon Aug 18 10:21:48 PDT 2014
  - Dep on Test::YAML 1.05
  1.07 Mon Aug 18 08:40:01 PDT 2014
  - Apply PR/8 from shlomif++. Add doc examples for YAML::Any.
  1.06 Sat Aug 16 16:51:08 PDT 2014
  - Change testdir to t
  1.05 Sat Aug 16 13:03:28 PDT 2014
  - Meta 0.0.2
  1.04 Sat Aug 16 04:28:10 PDT 2014
  - Eliminate spurious trailing whitespace
  1.03 Sat Aug 16 03:32:35 PDT 2014
  - Eliminate File::Basename from test/
  1.02 Fri Aug 15 21:09:54 PDT 2014
  - Add t/000-compile-modules.t
  1.01 Thu Aug  7 14:48:24 PDT 2014
  - Dep on patched Test::YAML
  1.00 Thu Aug  7 00:35:21 PDT 2014
  - Fix bad encoding in Pod
  0.99 Wed Aug  6 17:55:42 PDT 2014
  - Switch to external Test::Base
  0.98 Wed Jul 30 12:32:25 PDT 2014
  - Fix indexing of YAML::Any
  - Change IRC to irc.perl.org#yaml
* Fri Jul 25 2014 coolo@suse.com
- fixing license - GPL-1.0 is part of it
- updated to 0.97
  - Move remaining docs to Swim
  0.96 Sun Jul 13 22:54:08 PDT 2014
  - Fix Metadata and add Contributing file
  - Change Kwim to Swim
  0.95 Sat Jun 14 10:32:08 PDT 2014
  - Fix dumping blessed globs.
  0.94 Sat Jun 14 10:32:08 PDT 2014
  - Skip a failing test on 5.8 introduced in 0.93
  0.93 Fri Jun 13 22:32:18 PDT 2014
  - Switch to Zilla::Dist
  - Add badges to doc
  - @thorsteneckel++ fixed #18
  - @karenetheridge++ fixed #19
  0.92 Wed May 28 23:04:26 EDT 2014
  - https://github.com/ingydotnet/yaml-pm/pull/23
  0.91 Tue May 27 17:14:12 EDT 2014
  - https://github.com/ingydotnet/yaml-pm/pull/22
  0.90 Mon Feb 10 08:42:31 PST 2014
  - Revert Mo from 0.38 to 0.31 - zefram++ reported it breaking cpan client
  0.89 Sat Nov  8 12:51:48 PST 2014
  - Fixed tests to work under parallel testing -- kentnl
  - Switched to dzil release process
* Sat Feb  1 2014 lars@linux-schulserver.de
- update to 0.88:
  * Fixed YAML loading on perl 5.8 (broken in YAML 0.85) by removing
    5.10-specific regex construct. -- hobbs++
- changes from  0.87:
  * Using latest Test::Builder tp fix:
    https://rt.cpan.org/Public/Bug/Display.html?id=90847
- changes from 0.86:
  * Revert YAML::Mo for https://rt.cpan.org/Public/Bug/Display.html?id=90817
- changes from 0.85:
  * Fix for https://rt.cpan.org/Ticket/Display.html?id=19838 where
    synopsis in YAML::Dumper doesn't work as exptected.
  * Thorsten++ https://rt.cpan.org/Public/Bug/Display.html?id=90593
  * Upgrade to latest Mo
- changes from 0.84:
  * Resolve distribution error that caused .git to be shipped in the .tar.gz
- changes from  0.83:
  * Only call stat() and tell() on a filehandle if fileno existed
  * Explicit tied() call on globs to avoid a 5.16 deprecation warning
- changes from 0.82:
  * Test scalar @array rather than deprecated defined @array
    (Sebastian Stumpf)
* Fri Apr 20 2012 pascal.bleser@opensuse.org
- update to 0.81:
  * patch from https://rt.cpan.org/Public/Bug/Display.html?id=74826
  * YAML::Mo uses Safe Mo https://rt.cpan.org/Public/Bug/Display.html?id=76664
- changes from 0.80:
  * patch from https://rt.cpan.org/Ticket/Display.html?id=73702
  * make YAML::Node subclass YAML::Mo::Object as well as Exporter
- changes from 0.79:
  * noticed Mo::xxx causing problems on newer perls, removed xxx for now
- changes from 0.78:
  * deal with B::Deparse changes
* Sun Oct  2 2011 pascal.bleser@opensuse.org
- update to 0.77:
  * add $VERSION back to all modules
- changes from 0.76:
  * removed YAML::import
- changes from 0.75:
  * switch to Mo for OO (YAML::Mo)
- changes for 0.74:
  * switch to Module::Package
  * removed extra $VERSION lines from submodules
* Tue May 17 2011 coolo@opensuse.org
- updated to 0.73
  * Apply ANDK's patch for 5.14.0
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Sep  4 2010 chris@computersalat.de
- update to 0.72
  - Upgrade to Module::Install 1.00
  - Upgraded author tests via new ADAMK release automation
  - Normalise Ingy's name to ASCII in Makefile.PL so that we don't
    have Unicode in our own META.yml
- recreated by cpanspec 1.78
* Fri Apr 16 2010 chris@computersalat.de
- update to 0.71
  - Set file encoding to UTF-8 in LoadFile/DumpFile (RT#25434) by
    Olivier MenguÃ©
  - We shouldn't have to care about 5.8.0. Since it's causing
    CPAN Testers failures, bump the minimum Perl to 5.8.1
- update License
- fix deps perl-macros
- noarch package
* Tue Mar  9 2010 coolo@novell.com
- take out another reference to Test::Base to avoid cyclic dependencies
* Sun Jan 24 2010 coolo@novell.com
- clean up build requires again to fix build
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sun Dec 13 2009 chris@computersalat.de
- update to 0.70
  - Updated Module::Install dependency to 0.91
  - Bumping dependency to 5.8.0 but I think it's only in the test suite.
    However, I can't prove it. So if anyone wants 5.6 compatibility back
    you need to fix or rewrite the test suite.
- 0.69_02
  - Developer $VERSION now has eval correction
- 0.69_01
  - Added $VERSION to all modules
  - Removed the use of use base
  - Imported into the svn.ali.as repo
- cleanup spec
  * sort tags
  * updated url
  * fixed build-/deps
    added Test::Base >= 0.59
  * added provides cpan_name
  * update desc
  * add LICENSE to doc
* Mon Sep  7 2009 mls@suse.de
- remove bogus BuildRequires Test::Base
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 20 2009 chris@computersalat.de
- update to 0.68
  o Used update Test::Base to ensure Filter::Util::Call
- update to 0.67
  o Add YAML::Any
  o Move ysh to YAML::Shell
  o Add doc section explaining YAML::Old
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
* Mon Oct 27 2008 cwh@suse.de
- version: 0.66
  * Blessed code refs with LoadCode=0 still get blessed. rafl++
* Tue Jul 24 2007 cwh@suse.de
- version 0.65
  * \z is really \0
  * Speed up regexp loading. audreyt++
- version 0.64
  * Better support for loading regexps. audreyt++
- version 0.63
  * Don't emit nodes blessed into '' in the new tag scheme, and improve semantics
    of loading such nodes.
  * New support for dumping/loading regexps.
* Thu Oct 26 2006 cwh@suse.de
- version: 0.62
  - Patch from rgs for Catalyst users
- version: 0.61
  - New CGI.pm made test fail.
- version: 0.60
  - Changed object tag format in non backwards compatible way
  - Removed support for folded scalar emission
  - Added new tests
  - Sync with YAML::Syck
- version: 0.58
  - Fixed bug reported by Slaven Rezic on 5.8.0
  - Fixed a ysh bug reported on rt. 17589
- version: 0.57
  - Add obligatory '1;' to end of each module.
- version: 0.56
  - Add Module::Install::TestBase support
- version: 0.55
  - Load YAML::Node because Module::Build expects it to be loaded.
    We can undo this when Module::Build starts loading it for itself.
- version: 0.54
  - Remove dependency on Class::Spiffy (and/or Spiffy).
* Fri Feb 17 2006 cwh@suse.de
- Fixed dependency (wrong version of perl-Class-Spiffy)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 cwh@suse.de
  version 0.53
- Depend on Class::Spiffy instead of Spiffy. No source filtering.
  version 0.52
- Error in Spiffy-0.26 causing problems. Require 0.27
* Mon Jan 16 2006 cwh@suse.de
  version 0.51
- Tests pass on win32 and cygwin
- Don't gpg sign the distribution tarball
* Fri Jan 13 2006 cwh@suse.de
  version 0.50
- Major refactoring of YAML.pm
- Completely OO with same old functional UI
- Support the $YAML::Stringify option which most be on for objects to get
  stringified. Otherwise dump the object.
- Can dump overloaded objects now.
- Completely refactor test suite using Test::Base
- Create Test::YAML
- Make test framework compatible with YAML::Syck - Test-Base-0.45
- Reviewed all rt bugs. fixed many
- Reviewed all emailed bugs. Fixed many.
- Helped audrey complete YAML::Syck and worked on interoperability issues
- Test well known yaml docs like svk and META.yml
- Eliminate unsafe string evals
- Can use with autouse. Spiffy-0.25
- Support YAML::Marshall to help classes that want to do their own marshalling
- Make objects tags configurable
- -M option for ysh to test other implementations like YAML::Syck
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Tue Jul 19 2005 lmuelle@suse.de
- Update to 0.39.
* Thu Dec  4 2003 cwh@suse.de
- fixed filelist (vendorarch)
* Thu Dec  4 2003 cwh@suse.de
- initial revision
